@@ -28,8 +28,6 @@ import java.util.Date;
 import java.util.EnumSet;
 import java.util.List;
 
-import org.junit.Assert;
-
 import org.italiangrid.voms.VOMSError;
 import org.italiangrid.voms.VOMSValidators;
 import org.italiangrid.voms.ac.VOMSACValidator;
@@ -42,6 +40,7 @@ import org.italiangrid.voms.store.impl.DefaultVOMSTrustStore;
 import org.italiangrid.voms.test.utils.Fixture;
 import org.italiangrid.voms.test.utils.Utils;
 import org.italiangrid.voms.test.utils.VOMSAA;
+import org.junit.Assert;
 import org.junit.BeforeClass;
 import org.junit.Test;
 
@@ -55,8 +54,7 @@ public class TestACValidator implements Fixture {
   static VOMSACValidator validator;
 
   @BeforeClass
-  public static void setup() throws KeyStoreException, CertificateException,
-    IOException {
+  public static void setup() throws KeyStoreException, CertificateException, IOException {
 
     holder = Utils.getTestUserCredential();
     holder2 = Utils.getTest1UserCredential();
@@ -67,10 +65,8 @@ public class TestACValidator implements Fixture {
   @Test
   public void testValidityCheckSuccess() throws Exception {
 
-    ProxyCertificate proxy = Utils.getVOMSAA().createVOMSProxy(holder,
-      defaultVOFqans);
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    ProxyCertificate proxy = Utils.getVOMSAA().createVOMSProxy(holder, defaultVOFqans);
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     assertTrue(results.size() == 1);
     assertTrue(results.get(0).isValid());
     assertEquals(defaultVOFqans, results.get(0).getAttributes().getFQANs());
@@ -83,11 +79,12 @@ public class TestACValidator implements Fixture {
     Date start = Utils.getDate(1975, 12, 1);
     Date end = Utils.getDate(1975, 12, 2);
 
-    ProxyCertificate proxy = Utils.getVOMSAA().setAcNotBefore(start)
-      .setAcNotAfter(end).createVOMSProxy(holder, defaultVOFqans);
+    ProxyCertificate proxy = Utils.getVOMSAA()
+      .setAcNotBefore(start)
+      .setAcNotAfter(end)
+      .createVOMSProxy(holder, defaultVOFqans);
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     assertTrue(results.size() == 1);
 
@@ -96,46 +93,45 @@ public class TestACValidator implements Fixture {
     Assert.assertFalse(result.isValid());
     Assert.assertTrue(result.getValidationErrors().size() == 1);
     VOMSValidationErrorMessage m = result.getValidationErrors().get(0);
-    Assert.assertEquals(VOMSValidationErrorCode.acNotValidAtCurrentTime,
-      m.getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.acNotValidAtCurrentTime, m.getErrorCode());
   }
 
   @Test
   public void testHolderCheckFailure() throws Exception {
 
-    ProxyCertificate proxy = Utils.getVOMSAA().createVOMSProxy(holder, holder2,
-      defaultVOFqans, null, null);
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    ProxyCertificate proxy =
+        Utils.getVOMSAA().createVOMSProxy(holder, holder2, defaultVOFqans, null, null);
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     assertTrue(results.size() == 1);
 
     VOMSValidationResult result = results.get(0);
     Assert.assertFalse(result.isValid());
     Assert.assertTrue(result.getValidationErrors().size() == 1);
     VOMSValidationErrorMessage m = result.getValidationErrors().get(0);
-    Assert.assertEquals(VOMSValidationErrorCode.acHolderDoesntMatchCertChain,
-      m.getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.acHolderDoesntMatchCertChain, m.getErrorCode());
   }
 
   @Test
   public void testSignatureCheckFailure() throws Exception {
 
-    ProxyCertificate proxy = Utils.getVOMSAA().createVOMSProxy(holder,
-      defaultVOFqans);
+    ProxyCertificate proxy = Utils.getVOMSAA().createVOMSProxy(holder, defaultVOFqans);
     VOMSACValidator validator = Utils.getVOMSValidator(vomsdir_fake_aa_cert);
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     assertTrue(results.size() == 1);
     VOMSValidationResult result = results.get(0);
     Assert.assertFalse(result.isValid());
     Assert.assertTrue(result.getValidationErrors().size() == 2);
 
-    Assert.assertEquals(VOMSValidationErrorCode.lscFileNotFound, result
-      .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.lscFileNotFound,
+        result.getValidationErrors().get(0).getErrorCode());
+
+    Assert.assertEquals(VOMSValidationErrorCode.other,
+        result.getValidationErrors().get(1).getErrorCode());
+
     Assert.assertEquals(
-      VOMSValidationErrorCode.aaCertFailsSignatureVerification, result
-        .getValidationErrors().get(1).getErrorCode());
+        "Validation error: AuthorityKeyIdentifier in the AC  does not match AA certificate subject key identifier!",
+        result.getValidationErrors().get(1).getMessage());
 
   }
 
@@ -149,11 +145,9 @@ public class TestACValidator implements Fixture {
     X509CertChainValidatorExt certValidator = Utils.getCertificateValidator();
 
     VOMSACValidator validator = VOMSValidators.newValidator(
-      new DefaultVOMSTrustStore(Arrays.asList(vomsdir_expired_aa_cert)),
-      certValidator);
+        new DefaultVOMSTrustStore(Arrays.asList(vomsdir_expired_aa_cert)), certValidator);
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     assertTrue(results.size() == 1);
     VOMSValidationResult result = results.get(0);
@@ -161,20 +155,20 @@ public class TestACValidator implements Fixture {
 
     Assert.assertEquals(4, result.getValidationErrors().size());
 
-    Assert.assertEquals(VOMSValidationErrorCode.lscFileNotFound, result
-      .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.lscFileNotFound,
+        result.getValidationErrors().get(0).getErrorCode());
 
     // Certificate expired notification from CAnL
-    Assert.assertEquals(VOMSValidationErrorCode.canlError, result
-      .getValidationErrors().get(1).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.canlError,
+        result.getValidationErrors().get(1).getErrorCode());
 
     // This is probably a bug in CAnL: No valid CRL was found for the CA which
     // issued the chain. But this happens only when validating the expired cert.
-    Assert.assertEquals(VOMSValidationErrorCode.canlError, result
-      .getValidationErrors().get(2).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.canlError,
+        result.getValidationErrors().get(2).getErrorCode());
 
-    Assert.assertEquals(VOMSValidationErrorCode.invalidAaCert, result
-      .getValidationErrors().get(3).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.invalidAaCert,
+        result.getValidationErrors().get(3).getErrorCode());
 
   }
 
@@ -182,16 +176,14 @@ public class TestACValidator implements Fixture {
   public void testEmptyACCertsExtensionSuccess() throws Exception {
 
     VOMSAA aa = Utils.getVOMSAA();
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.INCLUDE_EMPTY_AC_CERTS_EXTENSION));
+    aa.setGenerationProperties(EnumSet.of(ACGenerationProperties.INCLUDE_EMPTY_AC_CERTS_EXTENSION));
 
     VOMSACValidator validator = Utils.getVOMSValidator();
 
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
@@ -199,16 +191,15 @@ public class TestACValidator implements Fixture {
     Assert.assertTrue(r.isValid());
     Assert.assertEquals(1, r.getValidationErrors().size());
 
-    Assert.assertEquals(VOMSValidationErrorCode.emptyAcCertsExtension, r
-      .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.emptyAcCertsExtension,
+        r.getValidationErrors().get(0).getErrorCode());
   }
 
   @Test
   public void testMissingACCertsExtensionFailure() throws Exception {
 
     VOMSAA aa = Utils.getVOMSAA();
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.SKIP_AC_CERTS_EXTENSION));
+    aa.setGenerationProperties(EnumSet.of(ACGenerationProperties.SKIP_AC_CERTS_EXTENSION));
 
     aa.setVoName("test.vo.2");
     aa.setHost("wilco.cnaf.infn.it");
@@ -216,11 +207,10 @@ public class TestACValidator implements Fixture {
 
     VOMSACValidator validator = Utils.getVOMSValidator();
 
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo.2"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo.2"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
@@ -229,11 +219,11 @@ public class TestACValidator implements Fixture {
 
     Assert.assertEquals(2, r.getValidationErrors().size());
 
-    Assert.assertEquals(VOMSValidationErrorCode.emptyAcCertsExtension, r
-      .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.emptyAcCertsExtension,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert.assertEquals(VOMSValidationErrorCode.aaCertNotFound, r
-      .getValidationErrors().get(1).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.aaCertNotFound,
+        r.getValidationErrors().get(1).getErrorCode());
 
   }
 
@@ -244,16 +234,14 @@ public class TestACValidator implements Fixture {
     aa.setVoName("test.vo.2");
     aa.setHost("wilco.cnaf.infn.it");
     aa.setCredential(Utils.getAACredential2());
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.FAKE_SIGNATURE_BITS));
+    aa.setGenerationProperties(EnumSet.of(ACGenerationProperties.FAKE_SIGNATURE_BITS));
 
     VOMSACValidator validator = Utils.getVOMSValidator();
 
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo.2"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo.2"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
 
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
@@ -261,38 +249,34 @@ public class TestACValidator implements Fixture {
     Assert.assertFalse(r.isValid());
     Assert.assertEquals(2, r.getValidationErrors().size());
 
-    Assert.assertEquals(
-      VOMSValidationErrorCode.acCertFailsSignatureVerification, r
-        .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.acCertFailsSignatureVerification,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert.assertEquals(VOMSValidationErrorCode.aaCertNotFound, r
-      .getValidationErrors().get(1).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.aaCertNotFound,
+        r.getValidationErrors().get(1).getErrorCode());
   }
 
   @Test
   public void testUnknownCriticalExtensionFailure() throws Exception {
 
     VOMSAA aa = Utils.getVOMSAA();
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.INCLUDE_FAKE_CRITICAL_EXTENSION));
+    aa.setGenerationProperties(EnumSet.of(ACGenerationProperties.INCLUDE_FAKE_CRITICAL_EXTENSION));
 
     VOMSACValidator validator = Utils.getVOMSValidator();
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
     Assert.assertFalse(r.isValid());
     Assert.assertEquals(1, r.getValidationErrors().size());
 
-    Assert.assertEquals(VOMSValidationErrorCode.other, r.getValidationErrors()
-      .get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.other,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert
-      .assertEquals(
+    Assert.assertEquals(
         "Validation error: unknown critical extension found in VOMS AC: 1.3.6.1.4.1.8005.100.120.82",
         r.getValidationErrors().get(0).getMessage());
   }
@@ -301,26 +285,22 @@ public class TestACValidator implements Fixture {
   public void testCriticalAKIDFailure() throws Exception {
 
     VOMSAA aa = Utils.getVOMSAA();
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.INCLUDE_CRITICAL_AKID_EXTENSION));
+    aa.setGenerationProperties(EnumSet.of(ACGenerationProperties.INCLUDE_CRITICAL_AKID_EXTENSION));
 
     VOMSACValidator validator = Utils.getVOMSValidator();
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
     Assert.assertFalse(r.isValid());
 
-    Assert.assertEquals(VOMSValidationErrorCode.other, r.getValidationErrors()
-      .get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.other,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert
-      .assertEquals(
-        "Validation error: AuthorityKeyIdentifier AC extension cannot be critical!",
+    Assert.assertEquals("Validation error: AuthorityKeyIdentifier AC extension cannot be critical!",
         r.getValidationErrors().get(0).getMessage());
   }
 
@@ -329,26 +309,24 @@ public class TestACValidator implements Fixture {
 
     VOMSAA aa = Utils.getVOMSAA();
 
-    aa.setGenerationProperties(EnumSet
-      .of(ACGenerationProperties.INCLUDE_CRITICAL_NO_REV_AVAIL_EXTENSION));
+    aa.setGenerationProperties(
+        EnumSet.of(ACGenerationProperties.INCLUDE_CRITICAL_NO_REV_AVAIL_EXTENSION));
 
     VOMSACValidator validator = Utils.getVOMSValidator();
-    ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"));
+    ProxyCertificate proxy =
+        aa.createVOMSProxy(Utils.getTestUserCredential(), Arrays.asList("/test.vo"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
     Assert.assertFalse(r.isValid());
 
-    Assert.assertEquals(VOMSValidationErrorCode.other, r.getValidationErrors()
-      .get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.other,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert.assertEquals(
-      "Validation error: NoRevAvail AC extension cannot be critical!", r
-        .getValidationErrors().get(0).getMessage());
+    Assert.assertEquals("Validation error: NoRevAvail AC extension cannot be critical!",
+        r.getValidationErrors().get(0).getMessage());
   }
 
   @Test
@@ -363,16 +341,14 @@ public class TestACValidator implements Fixture {
       localhostName = InetAddress.getLocalHost().getCanonicalHostName();
 
     } catch (UnknownHostException e) {
-      throw new VOMSError("Error resolving local hostname: " + e.getMessage(),
-        e);
+      throw new VOMSError("Error resolving local hostname: " + e.getMessage(), e);
     }
 
     VOMSACValidator validator = Utils.getVOMSValidator();
     ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"), null, Arrays.asList(localhostName));
+        Arrays.asList("/test.vo"), null, Arrays.asList(localhostName));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
@@ -386,17 +362,16 @@ public class TestACValidator implements Fixture {
 
     VOMSACValidator validator = Utils.getVOMSValidator();
     ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"), null, Arrays.asList("camaghe.cnaf.infn.it"));
+        Arrays.asList("/test.vo"), null, Arrays.asList("camaghe.cnaf.infn.it"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
     Assert.assertFalse(r.isValid());
     Assert.assertEquals(1, r.getValidationErrors().size());
-    Assert.assertEquals(VOMSValidationErrorCode.localhostDoesntMatchAcTarget, r
-      .getValidationErrors().get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.localhostDoesntMatchAcTarget,
+        r.getValidationErrors().get(0).getErrorCode());
 
   }
 
@@ -405,31 +380,27 @@ public class TestACValidator implements Fixture {
 
     VOMSAA aa = Utils.getVOMSAA();
 
-    VOMSACValidator validator = Utils
-      .getVOMSValidator(new LocalHostnameResolver() {
+    VOMSACValidator validator = Utils.getVOMSValidator(new LocalHostnameResolver() {
 
-        public String resolveLocalHostname() throws UnknownHostException {
+      public String resolveLocalHostname() throws UnknownHostException {
 
-          throw new UnknownHostException("misconfigured machine!");
-        }
-      });
+        throw new UnknownHostException("misconfigured machine!");
+      }
+    });
 
     ProxyCertificate proxy = aa.createVOMSProxy(Utils.getTestUserCredential(),
-      Arrays.asList("/test.vo"), null, Arrays.asList("camaghe.cnaf.infn.it"));
+        Arrays.asList("/test.vo"), null, Arrays.asList("camaghe.cnaf.infn.it"));
 
-    List<VOMSValidationResult> results = validator.validateWithResult(proxy
-      .getCertificateChain());
+    List<VOMSValidationResult> results = validator.validateWithResult(proxy.getCertificateChain());
     Assert.assertEquals(1, results.size());
     VOMSValidationResult r = results.get(0);
 
     Assert.assertFalse(r.isValid());
     Assert.assertEquals(1, r.getValidationErrors().size());
-    Assert.assertEquals(VOMSValidationErrorCode.other, r.getValidationErrors()
-      .get(0).getErrorCode());
+    Assert.assertEquals(VOMSValidationErrorCode.other,
+        r.getValidationErrors().get(0).getErrorCode());
 
-    Assert
-      .assertEquals(
-        "Validation error: Error resolving localhost name: misconfigured machine!",
+    Assert.assertEquals("Validation error: Error resolving localhost name: misconfigured machine!",
         r.getValidationErrors().get(0).getMessage());
   }
 }
